@@ -39,7 +39,7 @@
 
 #define DEF_FONT "Monospace 9"
 #ifdef WIN32
-#define DEF_FONT_ALTER "Arial Unicode MS,Lucida Sans Unicode,MS Gothic"
+#define DEF_FONT_ALTER "Arial Unicode MS,Lucida Sans Unicode,MS Gothic,Unifont"
 #endif
 
 void
@@ -580,9 +580,9 @@ const struct prefs vars[] = {
 	{"tab_trunc", P_OFFINT (truncchans), TYPE_INT},
 	{"tab_utils", P_OFFINT (windows_as_tabs), TYPE_BOOL},
 
-	{"text_auto_copy_color", P_OFFINT (autocopy_color), TYPE_BOOL},	
-	{"text_auto_copy_stamp", P_OFFINT (autocopy_stamp), TYPE_BOOL},
-	{"text_auto_copy_text", P_OFFINT (autocopy_text), TYPE_BOOL},
+	{"text_autocopy_color", P_OFFINT (autocopy_color), TYPE_BOOL},	
+	{"text_autocopy_stamp", P_OFFINT (autocopy_stamp), TYPE_BOOL},
+	{"text_autocopy_text", P_OFFINT (autocopy_text), TYPE_BOOL},
 	{"text_background", P_OFFSET (background), TYPE_STR},
 	{"text_color_nicks", P_OFFINT (colorednicks), TYPE_BOOL},
 #ifdef WIN32
@@ -597,7 +597,6 @@ const struct prefs vars[] = {
 	{"text_max_indent", P_OFFINT (max_auto_indent), TYPE_INT},
 	{"text_max_lines", P_OFFINT (max_lines), TYPE_INT},
 	{"text_replay", P_OFFINT (text_replay), TYPE_BOOL},
-	{"text_replay_strip_color", P_OFFINT (text_replay_strip_color), TYPE_BOOL},
 	{"text_search_case_match", P_OFFINT (text_search_case_match), TYPE_BOOL},
 	{"text_search_backward", P_OFFINT (text_search_backward), TYPE_BOOL},
 	{"text_search_highlight_all", P_OFFINT (text_search_highlight_all), TYPE_BOOL},
@@ -606,7 +605,9 @@ const struct prefs vars[] = {
 	{"text_show_marker", P_OFFINT (show_marker), TYPE_BOOL},
 	{"text_show_sep", P_OFFINT (show_separator), TYPE_BOOL},
 	{"text_spell_langs", P_OFFSET (spell_langs), TYPE_STR},
-	{"text_stripcolor", P_OFFINT (stripcolor), TYPE_BOOL},
+	{"text_stripcolor_msg", P_OFFINT (text_stripcolor_msg), TYPE_BOOL},
+	{"text_stripcolor_replay", P_OFFINT (text_stripcolor_replay), TYPE_BOOL},
+	{"text_stripcolor_topic", P_OFFINT (text_stripcolor_topic), TYPE_BOOL},
 	{"text_thin_sep", P_OFFINT (thin_separator), TYPE_BOOL},
 	{"text_tint_blue", P_OFFINT (tint_blue), TYPE_INT},
 	{"text_tint_green", P_OFFINT (tint_green), TYPE_INT},
@@ -689,7 +690,8 @@ load_config (void)
 	prefs.recon_delay = 10;
 	prefs.autocopy_text = 1;
 	prefs.text_replay = 1;
-	prefs.text_replay_strip_color = 1;
+	prefs.text_stripcolor_replay = 1;
+	prefs.text_stripcolor_topic = 1;
 	prefs.tabchannels = 1;
 	prefs.tab_layout = 2;	/* 0=Tabs 1=Reserved 2=Tree */
 	prefs.tab_sort = 1;
@@ -727,10 +729,10 @@ load_config (void)
 	prefs.autoopendccrecvwindow = 1;
 	prefs.autoopendccsendwindow = 1;
 	prefs.autoopendccchatwindow = 1;
-	prefs.userhost = 1;
+	/* prevent kicks and bans caused by overwhelming who'ing after reconnects */
+	/* prefs.userhost = 1; */
 	prefs.gui_chanlist_maxusers = 9999;
 	prefs.gui_chanlist_minusers = 5;
-	prefs.gui_url_mod = 4;	/* ctrl */
 	prefs.gui_tray = 1;
 	prefs.gui_pane_left_size = 100;
 	prefs.gui_pane_right_size = 100;
@@ -742,13 +744,14 @@ load_config (void)
 	prefs.input_tray_priv = prefs.input_tray_hilight = 1;
 	prefs.autodccsend = 2;	/* browse mode */
 	prefs.url_grabber = 1;
-	prefs.url_grabber_limit = 0; /* 0 means unlimited for backcompat */
+	prefs.url_grabber_limit = 100; /* 0 means unlimited */
 	prefs.text_search_follow = 1;
+	prefs.timestamp = 1;
 #ifdef WIN32
 	prefs.identd = 1;
 #endif
 	strcpy (prefs.spell_langs, g_getenv ("LC_ALL") ? g_getenv ("LC_ALL") : "en_US");
-	strcpy (prefs.stamp_format, "[%H:%M] ");
+	strcpy (prefs.stamp_format, "[%H:%M:%S] ");
 	strcpy (prefs.timestamp_log_format, "%b %d %H:%M:%S ");
 	strcpy (prefs.logmask, "%n-%c.log");
 	strcpy (prefs.nick_suffix, ",");
@@ -785,7 +788,7 @@ load_config (void)
 	strcpy (prefs.font_alternative, DEF_FONT_ALTER);
 #endif
 	strcpy (prefs.dnsprogram, "host");
-	strcpy (prefs.irc_no_hilight, "NickServ,ChanServ");
+	strcpy (prefs.irc_no_hilight, "NickServ,ChanServ,InfoServ,N,Q");
 
 	g_free ((char *)username);
 	g_free ((char *)realname);
