@@ -392,12 +392,18 @@ int
 waitline2 (GIOChannel *source, char *buf, int bufsize)
 {
 	int i = 0;
-	int len;
+	gsize len;
+	GError *error = NULL;
 
 	while (1)
 	{
-		if (g_io_channel_read (source, &buf[i], 1, &len) != G_IO_ERROR_NONE)
+		g_io_channel_set_buffered (source, FALSE);
+		g_io_channel_set_encoding (source, NULL, &error);
+
+		if (g_io_channel_read_chars (source, &buf[i], 1, &len, &error) != G_IO_STATUS_NORMAL)
+		{
 			return -1;
+		}
 		if (buf[i] == '\n' || bufsize == i + 1)
 		{
 			buf[i] = 0;
@@ -1365,10 +1371,12 @@ int my_poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
 int
 util_exec (const char *cmd)
 {
-	int pid;
 	char **argv;
 	int argc;
+#ifndef WIN32
+	int pid;
 	int fd;
+#endif
 
 	if (my_poptParseArgvString (cmd, &argc, &argv) != 0)
 		return -1;
@@ -1398,9 +1406,9 @@ util_exec (const char *cmd)
 int
 util_execv (char * const argv[])
 {
+#ifndef WIN32
 	int pid, fd;
 
-#ifndef WIN32
 	pid = fork ();
 	if (pid == -1)
 		return -1;
