@@ -351,6 +351,10 @@ session_new (server *serv, char *from, int type, int focus)
 	session *sess;
 
 	sess = malloc (sizeof (struct session));
+	if (sess == NULL)
+	{
+		return NULL;
+	}
 	memset (sess, 0, sizeof (struct session));
 
 	sess->server = serv;
@@ -591,7 +595,7 @@ static char defaultconf_commands[] =
 	"NAME DIALOG\n"		"CMD query %2\n\n"\
 	"NAME DMSG\n"			"CMD msg =%2 &3\n\n"\
 	"NAME EXIT\n"			"CMD quit\n\n"\
-	"NAME GREP\n"			"CMD lastlog -r &2\n\n"\
+	"NAME GREP\n"			"CMD lastlog -r -- &2\n\n"\
 	"NAME IGNALL\n"			"CMD ignore %2!*@* ALL\n\n"\
 	"NAME J\n"				"CMD join &2\n\n"\
 	"NAME KILL\n"			"CMD quote KILL %2 :&3\n\n"\
