@@ -22,7 +22,9 @@
 #include <fcntl.h>
 #include <time.h>
 
-#ifndef WIN32
+#ifdef WIN32
+#include <io.h>
+#else
 #include <unistd.h>
 #endif
 
@@ -54,6 +56,7 @@
 #include "../common/server.h"
 #include "gtkutil.h"
 #include "maingui.h"
+#include "menu.h"
 
 
 #include "custom-list.h"
@@ -527,7 +530,7 @@ chanlist_save (GtkWidget * wid, server *serv)
 
 	if (gtk_tree_model_get_iter_first (model, &iter))
 		gtkutil_file_req (_("Select an output filename"), chanlist_filereq_done,
-								serv, NULL, FRF_WRITE);
+								serv, NULL, NULL, FRF_WRITE);
 }
 
 static gboolean
@@ -545,6 +548,7 @@ static void
 chanlist_minusers (GtkSpinButton *wid, server *serv)
 {
 	serv->gui->chanlist_minusers = gtk_spin_button_get_value_as_int (wid);
+	prefs.gui_chanlist_minusers = serv->gui->chanlist_minusers;
 
 	if (serv->gui->chanlist_minusers < serv->gui->chanlist_minusers_downloaded)
 	{
@@ -565,6 +569,7 @@ static void
 chanlist_maxusers (GtkSpinButton *wid, server *serv)
 {
 	serv->gui->chanlist_maxusers = gtk_spin_button_get_value_as_int (wid);
+	prefs.gui_chanlist_maxusers = serv->gui->chanlist_maxusers;
 }
 
 static void
@@ -733,10 +738,24 @@ chanlist_opengui (server *serv, int do_refresh)
 	serv->gui->chanlist_data_stored_rows = NULL;
 
 	if (!serv->gui->chanlist_minusers)
-		serv->gui->chanlist_minusers = 5;
+	{
+		if (prefs.gui_chanlist_minusers < 1 || prefs.gui_chanlist_minusers > 999999)
+		{
+			prefs.gui_chanlist_minusers = 5;
+		}
+
+		serv->gui->chanlist_minusers = prefs.gui_chanlist_minusers;
+	}
 
 	if (!serv->gui->chanlist_maxusers)
-		serv->gui->chanlist_maxusers = 9999;
+	{
+		if (prefs.gui_chanlist_maxusers < 1 || prefs.gui_chanlist_maxusers > 999999)
+		{
+			prefs.gui_chanlist_maxusers = 9999;
+		}
+
+		serv->gui->chanlist_maxusers = prefs.gui_chanlist_maxusers;
+	}
 
 	serv->gui->chanlist_window =
 		mg_create_generic_tab ("ChanList", tbuf, FALSE, TRUE, chanlist_closegui,
