@@ -53,8 +53,11 @@
 #include "pixmaps.h"
 
 #ifdef WIN32
+#include <io.h>
+#if 0	/* native file dialogs */
 #include "../common/fe.h"
 #include "../common/thread.h"
+#endif
 #else
 #include <unistd.h>
 #endif
@@ -71,12 +74,14 @@ struct file_req
 	filereqcallback callback;
 	int flags;		/* FRF_* flags */
 
+#if 0	/* native file dialogs */
 #ifdef WIN32
 	int multiple;
 	thread *th;
 	char *title;	/* native locale */
 	char *filter;
 #endif
+#endif
 };
 
 static char last_dir[256] = "";
@@ -178,6 +183,7 @@ gtkutil_file_req_response (GtkWidget *dialog, gint res, struct file_req *freq)
 	}
 }
 
+#if 0	/* native file dialogs */
 #ifdef WIN32
 static int
 win32_openfile (char *file_buf, int file_buf_len, char *title_text, char *filter,
@@ -361,15 +367,20 @@ win32_read_thread (GIOChannel *source, GIOCondition cond, struct file_req *freq)
 	return FALSE;
 }
 #endif
+#endif	/* native file dialogs */
 
 void
-gtkutil_file_req (const char *title, void *callback, void *userdata, char *filter,
+gtkutil_file_req (const char *title, void *callback, void *userdata, char *filter, char *extensions,
 						int flags)
 {
 	struct file_req *freq;
 	GtkWidget *dialog;
+	GtkFileFilter *filefilter;
 	extern char *get_xdir_fs (void);
+	char *token;
+	char *tokenbuffer;
 
+#if 0	/* native file dialogs */
 #ifdef WIN32
 	if (!(flags & FRF_WRITE))
 	{
@@ -420,6 +431,7 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 
 	return;
 	}
+#endif
 #endif
 
 	if (flags & FRF_WRITE)
@@ -436,10 +448,9 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), temp);
 			gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), file_part (filter));
 		}
-#if GTK_CHECK_VERSION(2,8,0)
+
 		if (!(flags & FRF_NOASKOVERWRITE))
 			gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
-#endif
 	}
 	else
 		dialog = gtk_file_chooser_dialog_new (title, NULL,
@@ -465,6 +476,22 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), filter);
 	}
 
+	if (flags & FRF_EXTENSIONS && extensions != NULL)
+	{
+		filefilter = gtk_file_filter_new ();
+		tokenbuffer = g_strdup (extensions);
+		token = strtok (tokenbuffer, ";");
+
+		while (token != NULL)
+		{
+			gtk_file_filter_add_pattern (filefilter, token);
+			token = strtok (NULL, ";");
+		}
+
+		g_free (tokenbuffer);
+		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filefilter);
+	}
+
 	freq = malloc (sizeof (struct file_req));
 	freq->dialog = dialog;
 	freq->flags = flags;
@@ -637,8 +664,10 @@ gtkutil_button (GtkWidget *box, char *stock, char *tip, void *callback,
 		gtk_widget_show (bbox);
 
 		img = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_MENU);
-		if (stock == GTK_STOCK_GOTO_LAST)
+		if (strcmp (stock, GTK_STOCK_GOTO_LAST) == 0)
+		{
 			gtk_widget_set_usize (img, 10, 6);
+		}
 		gtk_container_add (GTK_CONTAINER (bbox), img);
 		gtk_widget_show (img);
 		gtk_box_pack_start (GTK_BOX (box), wid, 0, 0, 0);
