@@ -54,6 +54,7 @@
 #include "../common/modes.h"
 #include "../common/url.h"
 #include "../common/util.h"
+#include "../common/text.h"
 
 #include "fe-gtk.h"
 #include "banlist.h"
@@ -1240,7 +1241,7 @@ mg_open_quit_dialog (gboolean minimize_button)
 
 	dialog = gtk_dialog_new ();
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Quit XChat?"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Quit HexChat?"));
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent_window));
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
@@ -2801,7 +2802,10 @@ mg_inputbox_rightclick (GtkEntry *entry, GtkWidget *menu)
 static void
 mg_create_entry (session *sess, GtkWidget *box)
 {
-	GtkWidget *sw, *hbox, *but, *entry;
+	GtkWidget *hbox, *but, *entry;
+#ifdef USE_GTKSPELL
+	GtkWidget *sw;
+#endif
 	session_gui *gui = sess->gui;
 
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -3695,7 +3699,9 @@ mg_drag_motion_cb (GtkWidget *widget, GdkDragContext *context, int x, int y, gui
 	GdkGCValues val;
 	int half, width, height;
 	int ox, oy;
+#if 0
 	GtkPaned *paned;
+#endif
 	GdkDrawable *draw;
 
 	/* ignore file drops */
