@@ -1235,7 +1235,7 @@ menu_search_prev ()
 	xtext_buffer *buf = xtext->buffer;
 
 	if (!gtk_xtext_search(xtext, buf->search_text,
-		(buf->search_flags & (case_match | follow | regexp) | backward), NULL))
+		(buf->search_flags & (case_match | follow | regexp)) | backward, NULL))
 	{
 		fe_message (_("Search hit end, not found."), FE_MSG_ERROR);
 	}
@@ -1521,7 +1521,7 @@ menu_ctcpguiopen (void)
 static void
 menu_docs (GtkWidget *wid, gpointer none)
 {
-	fe_open_url ("http://xchat.org/docs/");
+	fe_open_url ("http://www.hexchat.org/");
 }
 
 /*static void
